@@ -167,3 +167,27 @@ def PlotFit(time, ydat, par, sterr, xyunits, law='lin', inlog=False, export_file
     if export_file:
         plt.savefig(export_file)
     # plt.show()
+
+def read_ConfFile(FileAddress:str):
+    '''
+    Reading JUDAS configuration files. 
+
+    Parameters
+    ----------
+    FileAddress : str
+        Full address of configuration file.
+
+    Returns
+    -------
+    Par_Dict : dict
+        Dictionary with all user defined variables in the respective workflow.
+
+    '''
+    Par_Dict = dict()
+    with open(FileAddress) as fp:
+        mylines = fp.read().splitlines()
+        for myline in mylines:
+            if not myline.startswith('#'):
+                (key, val) = myline.split(':', 1)
+                Par_Dict[str(key.strip())] = val.strip()
+    return Par_Dict
\ No newline at end of file
